Skip to contents

Returns the selected outcome-adaptive lasso propensity score coefficients (intercept first), either on the original covariate scale (default; the scale used by predict.oal()) or on the standardized scale that the penalized objective was actually optimized on (the scale of the adaptive weights and of the wAMD – methods-paper material).

Usage

# S3 method for class 'oal'
coef(object, scale = c("original", "standardized"), ...)

Arguments

object

An oal object.

scale

"original" (default) or "standardized".

...

Ignored.

Value

A named numeric vector of length p + 1.

See also